import setuptools
from os.path import dirname
from glob import glob

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

# Package list is autogenerated to be any 'perceval' subfolder containing a __init__.py file
package_list = [dirname(p).replace('\\', '.') for p in glob('perceval/**/__init__.py', recursive=True)]

QISKIT_BRIDGE_PKGS = ["qiskit~=0.46.3", "seaborn~=0.13"]
QUTIP_BRIDGE_PKGS = ["qutip~=5.0.4"]
MYQLM_BRIDGE_PKGS = ["myqlm~=1.10.4"]
CQASM_BRIDGE_PKGS = ["libqasm==0.6.7"]  # libqasm is not stable enough to put ~=

setuptools.setup(
    name="perceval-quandela",
    author="quandela",
    author_email="perceval@quandela.com",
    description="A powerful Quantum Photonic Framework",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Quandela/Perceval",
    project_urls={
        "Documentation": "https://perceval.quandela.net/docs/",
        "Source": "https://github.com/Quandela/Perceval",
        "Tracker": "https://github.com/Quandela/Perceval/issues"
    },
    classifiers=[
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Programming Language :: Python :: 3.13",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    packages=package_list,
    install_requires=['sympy~=1.12', 'numpy>=1.26,<3', 'scipy~=1.13', 'tabulate~=0.9', 'matplotlib<4', 'exqalibur~=0.6.2',
                      'multipledispatch<2', 'protobuf>=3.20.3', 'drawsvg>=2.0', 'requests<3',
                      'networkx~=3.1', 'latexcodec<4', 'platformdirs<5', 'tqdm',
                      "typing_extensions; python_version == '3.9'"  # TODO: remove when dropping 3.9
                      ],
    extras_require={
        "qiskit_bridge": QISKIT_BRIDGE_PKGS,
        "qutip_bridge": QUTIP_BRIDGE_PKGS,
        "myqlm_bridge": MYQLM_BRIDGE_PKGS,
        "cqasm_bridge": CQASM_BRIDGE_PKGS,
        "all": QISKIT_BRIDGE_PKGS+QUTIP_BRIDGE_PKGS+MYQLM_BRIDGE_PKGS+CQASM_BRIDGE_PKGS
    },
    setup_requires=["scmver"],
    python_requires=">=3.9,<3.14",
    scmver=True
)
